.. include:: ../README.rst
.. include:: ../AUTHORS.rst

==============================
Versions of this Documentation
==============================

.. raw:: html

   <iframe
   src="https://molssi-seamm.github.io/from_smiles_step/dev/versions.html"
   title="Documentation Versions"  style="border:none;">
   </iframe>

.. toctree::
   :hidden:
   :maxdepth: 1
   :titlesonly:

   user/index
   developer/index
   authors
   history

.. toctree::
   :hidden:
   :maxdepth: 1
   :titlesonly:

   Main SEAMM documentation <https://molssi-seamm.github.io>
